@@ -1,7 +1,8 @@
 \dontrun{
-## Unfold the joint size-shape-orientation
-## distribution of intersection ellipses
-## given in the data set `data15p`
+
+## Unfolding of the joint size-shape-orientation
+## distribution of intersection ellipses of
+## the data set `data15p`
 
 library(unfoldr)
 library(parallel)
@@ -9,16 +10,20 @@ options(par.unfoldr=detectCores())
 
 # load ellipse intersection parameters
 data(data15p)
+
 # construct section profiles
-AC <- data.matrix(data15p[c("A","C")])/1000 # unit: micro meter	
+AC <- data.matrix(data15p[c("A","C")])/1000
+
 # for prolates: selecting the minor semi-axis lengths
 # independent of nomenclature, which is always sp$A
-sp <- sectionProfiles(AC,as.numeric(unlist(data15p["alpha"])))
-
+sp <- sectionProfiles(AC,unlist(data15p["alpha"]))
+summary(sp$alpha)
+	
 # set number of bins for each parameter
 bin <- c(14,16,18)
 # unfold the joint distribution
 ret <- unfold(sp,bin,kap=1.25)
+
 ## optional: histogram plot
 # library(rgl)
 # trivarHist(ret$N_V,main="Trivariate Histogram (3d estimated)",scale=1.2)
@@ -34,7 +39,7 @@ hist(paramEst$a,
 		main=expression(paste("Minor semi-axis ",hat(c))),
 		breaks=breaks$size,
 		right=FALSE,freq=FALSE,col="gray",
-		xlab=expression(hat(a)),ylim=c(0,135))
+		xlab=expression(hat(c)))
 
 # Theta
 hist(paramEst$Theta[paramEst$Theta<max(breaks$angle)],
@@ -43,9 +48,9 @@ hist(paramEst$Theta[paramEst$Theta<max(breaks$angle)],
 		xlab=expression(theta),ylim=c(0,2.25))
 
 # shape
-hist(paramEst$s,main=expression(paste("Shape ", hat(s))),
+hist(paramEst$s,main=expression(paste("Shape ",hat(s))),
 		breaks=breaks$shape,xlim=c(0,1),ylim=c(0,5),
 		right=FALSE,freq=FALSE,col="gray",xlab=expression(hat(s)))
-
 par(op)
+
 }
